%Tboil_vs_p_analysis
% Loads Excel sheet 'Tboil vs pressure.xlsx' containing raw experimental
% data and constructs graphs ( ln(p) vs 1/Tboil linearized, and p vs Tboil)
% and performs regression analysis to determine molar latent heat of
% vaporization.
%
% LAST UPDATED by Andy French Nov 2019

function Tboil_vs_p_analysis

%Molar gas constant R /J/mol/K
R = 8.314;

%Molar mass of water vapour /kg/mol
Mw = 18.01528*1e-3;

%Boiling point at STP (pressure P100 in kPa, T100 in K)
P100 = 101.325; T100 = 100 + 273;

%Errors in T and P meaurements (+/- in K and kPa respectively)
sigma_T = 0.3; sigma_p = 0.2;

%Fontsize for graphs
fsize = 18;

%

%Dsiplay message to command window
disp(' ')
disp(' %%%% Boiling point of water vs pressure analysis %%%%' );
disp(' ');

%Import Excel sheet 'Tboil vs pressure.xlsx'
disp(' ... Importing raw data from Excel sheet');
[num,txt,raw] = xlsread( 'Tboil vs pressure.xlsx' );

%Extract data
Tboil_degC = num(7:end,1);
Tambient_degC = num(7:end,3);
P_kPa = num(7:end,2);

%Determine axis of linearized graph based upon Boltzmann factor (of
%Clausius Clapeyron equation P vs T model)
disp(' ... Performing regression analysis ');
x = 1000./( Tboil_degC + 273 ); y = log( P100./P_kPa );

%Determine line of best fit
[yfit,xfit,r,m,c,dm,dc,yupper,ylower,s] = bestfitc(x,y);

%Determine Lvap (in kJ/mol) 
Lvap_gradient = m*R; Lvap_gradient_error = dm*R;
Lvap_intercept = -c*R*T100/1000; Lvap_intercept_error = dc*R*T100/1000;
disp(' ');
disp([' Molar Lvap from gradient = (',num2str(Lvap_gradient,3),...
    ' +/-',num2str(Lvap_gradient_error,1),') kJ/mol']);
disp([' Molar Lvap from intercept = (',num2str(Lvap_intercept,3),...
    ' +/-',num2str(Lvap_intercept_error,1),') kJ/mol']);

%Determine model P vs T curve
Lvap = Lvap_gradient*1000;
T = linspace( 40, 100, 1000 );
p = P100*exp( Lvap/(R*T100) )*exp( -Lvap./(R*(T+273)) );

%Plot linearized graph
disp(' ');
disp(' ... Plotting graphs');
plot( xfit,yfit,'b-',x,y,'r+','markersize',18); hold on;
plot( xfit,yupper,'b--',xfit,ylower,'b--'); hold on;
xlabel('1000/T_{boil}  (K^{-1})','fontsize',fsize);
ylabel('ln( P_{100} / P )','fontsize',fsize);
title( ['ln( P_{100} / P ) vs 1/T_{boil}.  L_{vap}= (',...
    num2str(Lvap_gradient,3),' +/-',num2str(Lvap_gradient_error,1),') kJ/mol'],'fontsize',fsize);
set(gca,'fontsize',fsize); grid on;
print(gcf,'linearized ln(p) vs 1 over Tboil.png','-dpng','-r300');
clf;

%Plot p vs T underlaid with model curve
plot( T,p,'b-',Tboil_degC,P_kPa,'r+','markersize',18); hold on;
xlabel('Boiling temperature / ^oC','fontsize',fsize);
ylabel('Pressure /kPa','fontsize',fsize);
title( ['Pressure vs boiling temperature. L_{vap}= (',...
    num2str(Lvap_gradient,3),' +/-',num2str(Lvap_gradient_error,1),') kJ/mol'],'fontsize',fsize);
set(gca,'fontsize',fsize); grid on;
print(gcf,'p vs Tboil.png','-dpng','-r300');
close(gcf);
disp(' ');
disp(' Analysis complete.')
disp(' ');

%%

%Line of best fit function yfit = m*x +c, with product moment correlation
%coefficient r
function [yfit,xfit,r,m,c,dm,dc,yupper,ylower,s] = bestfitc(x,y)

%Find any x or y values that are NaN or Inf
ignore = isnan(abs(x)) | isnan(abs(y)) | isinf(abs(x)) | isinf(abs(y));
x(ignore) = []; y(ignore) = [];
n = length(x);

%Compute line of best fit
xbar = mean(x); ybar = mean(y); xybar = mean(x.*y);
xxbar = mean(x.^2 ); yybar = mean(y.^2 );
Vx = xxbar - xbar^2; Vy = yybar - ybar^2;
COVxy = xybar - xbar*ybar;
m = COVxy/Vx; c = ybar - m*xbar; r = COVxy/sqrt( Vx*Vy );
[x,i] = sort(x); y = y(i);
yfit = m*x + c; xfit = x;

%Compute errors in gradient m and intercept c
s = sqrt( (1/(n-2))*sum( (y - yfit).^2 ) );
dm = s/sqrt(n*Vx);
dc = ( s/sqrt(n) )*sqrt( 1 + (xbar^2)/Vx );

%Determine envelope lines
yupper = (m+dm)*x + c - dc;
ylower = (m-dm)*x + c + dc;

%End of code